@@ -12,11 +12,8 @@ my $mysql = Test::mysqld->new
 {
     no warnings "redefine";
     sub t::Utils::setup {
-        my ($class, $table) = @_;
         my $dbh = DBI->connect($mysql->dsn( dbname => "test" ));
-        my $schema = t::Utils::_get_schema($dbh, $table);
-        $schema =~ s/CREATE TABLE/CREATE TABLE IF NOT EXISTS/;
-        $dbh->do($schema);
+        $dbh->do(t::Utils::_get_schema($dbh));
         $dbh;
     }
 }
